@@ -3,10 +3,14 @@ from django.db import models
 from django.db.models.signals import post_save, pre_save
 from django.dispatch import receiver
 
+from ai_django_core.managers import GloballyVisibleQuerySet
+
 
 class MySingleSignalModel(models.Model):
     value = models.PositiveIntegerField(default=0)
 
+    objects = GloballyVisibleQuerySet.as_manager()
+
 
 @receiver(pre_save, sender=MySingleSignalModel)
 def increase_value_no_dispatch_uid(sender, instance, **kwargs):
